package com.ihealth.sample.helloworld;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.jbpm.process.instance.impl.demo.SystemOutWorkItemHandler;
import org.jbpm.test.JbpmJUnitBaseTestCase;
import org.junit.Test;
import org.kie.api.runtime.KieSession;
import org.kie.api.runtime.manager.RuntimeEngine;
import org.kie.api.runtime.process.ProcessInstance;
import org.kie.api.task.TaskService;
import org.kie.api.task.model.TaskSummary;

/**
 * Test the process HelloWorldProcess.bpmn2
 */
public class HelloWorldProcessTest
  extends JbpmJUnitBaseTestCase
{

  public HelloWorldProcessTest() {
    // setup data source, enable persistence
    super(true, true);
  }

  @Test
  public void testProcess() {
    String userId = "rtubati";
    createRuntimeManager("com/ihealth/sample/helloworld/HelloWorldProcess.bpmn2");

    // take RuntimeManager to work with process engine
    RuntimeEngine runtimeEngine = getRuntimeEngine();

    // get access to KieSession instance
    KieSession ksession = runtimeEngine.getKieSession();
    ksession.getWorkItemManager().registerWorkItemHandler("Sysout", new SystemOutWorkItemHandler());

    // start process
    Map<String, Object> params = new HashMap<String, Object>();
    params.put("pUserName", userId);
    ProcessInstance processInstance = ksession.startProcess("HelloWorld.HelloWorldProcess", params);

    // check what nodes have been triggered
    assertNodeTriggered(processInstance.getId(), "Start", "Sysout", "HelloWorldTask");

    // Get task, start and complete with parameters
    TaskService taskService = runtimeEngine.getTaskService();
    List<TaskSummary> tasks = taskService.getTasksAssignedAsPotentialOwner(userId, "en-UK");
    TaskSummary task = tasks.get(0);
    taskService.start(task.getId(), userId);
    Map<String, Object> taskParams = new HashMap<String, Object>();
    taskParams.put("tUserComment", "Here is the user comment from human task");
    taskService.complete(task.getId(), userId, taskParams);

    assertNodeTriggered(processInstance.getId(), "Print User Comment", "End");

    // check whether the process instance has completed successfully
    assertProcessInstanceCompleted(processInstance.getId(), ksession);
  }
}
